@@ -5,7 +5,7 @@ from flib.output import configure_logger
 from flib import configured
 from flib import abort
 
-log = configure_logger('test_flow')
+log = configure_logger('simple_flow')
 
 repo = configured.path_obj(git=True)
 
@@ -36,13 +36,15 @@ def feature(ftargs):
     '''
     log.debug(ftargs)
     name = ftargs.NAME
-    feature = ft.makeit(name)
-    repo.git('checkout', feature)
 
     if ftargs.new:
+        feature = ft.makeit(name)
         return new_feature(feature)
 
-    elif ftargs['--update']:
+    feature = repo.get_branch(name)
+    repo.git('checkout', feature)
+
+    if ftargs['--update']:
         return update_feature(feature)
 
     elif ftargs.continued:
@@ -72,3 +74,9 @@ def finish_feature(feature, update_result):
 
 def continued_feature(feature):
     log.info('Sry, not yet impl. ;-p')
+
+
+@expose
+def remaster():
+    '''Update all branches based on master.'''
+
